![Image](https://github.com/TimHenry1995/gyoza/blob/develop/docs/images/logo.png?raw=true)
## Installation
```
pip install gyoza
```

## Documentation
Detailed documentation can be found on the companion website of [read-the-docs](https://gyoza.readthedocs.io/en/latest/)

## Tutorial
A tutorial can be found in the [tutorials](https://github.com/TimHenry1995/gyoza/tree/main/tutorials) folder of the Github repository.

## Experiments
Experiments can be found in the [experiments](https://github.com/TimHenry1995/gyoza/tree/main/experiments) folder of the Github repository.

## Development
Developers can access the package via [GitHub](https://github.com/TimHenry1995/gyoza)

